@@ -1,13 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "themeeditorutil.h"
 
-ThemeEditorUtil::ThemeEditorUtil()
-{
-}
+ThemeEditorUtil::ThemeEditorUtil() = default;
 
 QString ThemeEditorUtil::defaultMail() const
 {
